@@ -4,7 +4,6 @@ from enum import Enum
 from typing import Union, Dict, List
 
 import aiohttp
-from asyncio_throttle import Throttler
 
 from aioetherscan.exceptions import EtherscanClientContentTypeError, EtherscanClientError, EtherscanClientApiError, \
     EtherscanClientProxyError
@@ -30,13 +29,13 @@ class Network:
         self._set_network(network)
 
         self._loop = loop or asyncio.get_event_loop()
-        self._session = aiohttp.ClientSession(loop=self._loop)
-        self._throttler = Throttler(rate_limit=5)
+        self._session = None
 
         self._logger = logging.getLogger(__name__)
 
     async def close(self):
-        await self._session.close()
+        if self._session is not None:
+            await self._session.close()
 
     async def get(self, params: Dict = None) -> Union[Dict, List, str]:
         return await self._request(HttpMethod.GET, params=self._filter_and_sign(params))
@@ -45,11 +44,12 @@ class Network:
         return await self._request(HttpMethod.POST, data=self._filter_and_sign(data))
 
     async def _request(self, method: HttpMethod, data: Dict = None, params: Dict = None) -> Union[Dict, List, str]:
+        if self._session is None:
+            self._session = aiohttp.ClientSession(loop=self._loop)
         session_method = getattr(self._session, method.value)
-        async with self._throttler:
-            async with session_method(self._API_URL, params=params, data=data) as response:
-                self._logger.debug('[%s] %r %r %s', method.name, str(response.url), data, response.status)
-                return await self._handle_response(response)
+        async with session_method(self._API_URL, params=params, data=data) as response:
+            self._logger.debug('[%s] %r %r %s', method.name, str(response.url), data, response.status)
+            return await self._handle_response(response)
 
     async def _handle_response(self, response: aiohttp.ClientResponse) -> Union[Dict, list, str]:
         try:
